<?php
/**
 * Main Controller
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Main_Controller extends Me_Controller
{
    /**
     * Controller名
     */
    protected $controller = 'Main';
    /**
     * Logicオブジェクト
     * @var Main_Logic
     */
    protected $logic;

    /**
     * 管理画面トップ
     */
    public function index()
    {
        $page_path = Me_Util::get_query_string('path', '/');
        $src = SITE_PATH . $page_path;
        $home = SITE_PATH;
        $url = '';
        if (empty($home)) {
            $home = '/';
        }
        if ($_COOKIE['siteview_href']) {
            $src = $_COOKIE['siteview_href'];
            $url = $src;
        } else {
            $url = ($_SERVER['HTTPS'] === 'on') ? 'https://' : 'http://';
            $url .= $_SERVER["HTTP_HOST"] . $src;
        }
        
        $this->set_data(compact('src', 'home', 'url'));
    }

    /**
     * サイトビューで開いているページの情報を返す
     */
    public function get_info()
    {
        $url = urldecode(Me_Util::get_post_data('url', ''));
        $path = parse_url($url, PHP_URL_PATH);
        if (strlen($path) < 1) {
            $path = '/';
        }
        list($page, $rows) = $this->logic->get_info($path);
        
        $access_priv = false;
        if (isset($page)) {
            // アクセス権の確認
            $user_logic = new User_Logic();
            $access_priv = $user_logic->check_access_priv($page['page_path']);
        }
        $this->set_data(compact('page', 'rows', 'access_priv'));
    }

    /**
     * ログアウト処理
     */
    public function logout()
    {
        // POSTされていなければエラー
        if (empty($_POST)) {
            throw new Me_Exception(401);
        }

        // ログアウト処理実行
        $user_logic = new User_Logic();
        $user_logic->logout();

        // topにリダイレクト
        $this->redirect_path = '../Main/index';
    }

    /**
     * 空ページを返す
     */
    public function empty_page()
    {
        $this->view = null;
    }

    /**
     * フォームIDで管理しているフォームを削除する
     */
    public function unset_form()
    {
        Me_Util::unset_form();
        $this->view = null;
    }
}