<?php
/**
 * Metag Img
 * @package     Metag
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Metag_Img extends Metag
{
    /** No Imageファイル */
    const NO_IMAGE = '/app/assets/img/noimage.gif';
    /** resizeの幅と高さの区切り文字 */
    const RESIZE_SEPARATOR = 'x';
    /**
     * タグタイプ
     * @var string
     */
    public $node_type = 'img';
    /**
     * 表示名
     * @var string
     */
    public $display_name = '画像 (img)';
    /**
     * ブロック要素かどうか
     * @var boolean
     */
    public $is_block = false;
    /**
     * 除外属性
     * @var string
     */
    public $exclude_attr;
    /**
     * src属性
     * @var string
     */
    public $src;
    /**
     * リサイズ指定
     * @var string
     */
    public $resize;
    /**
     * 画像ファイル名サフィックス
     * @var string
     */
    public $suffix;
    /**
     * セルフリンク指定
     * @var string
     */
    public $self_link;
    /**
     * align属性
     * @var string
     */
    public $align;
    /**
     * style attribute
     * @var string
     */
    public $style;
    /**
     * 固定ファイル名
     * @var string
     */
    public $file_name;
    /**
     * 属性リスト
     * @var array
     */
    public $attr_list = array(
        'id' => 'id',
        'resize' => 'resize',
        'suffix' => 'suffix',
        'self_link' => 'self_link',
        'initial_value' => 'initial_value',
        'style' => 'style',
        'anchor' => 'anchor',
        'ref_id' => 'ref_id',
        'ref_page_id' => 'ref_page_id',
        'ref_link' => 'ref_link',
        'file_name' => 'file_name',
        'exclude_attr' => 'exclude_attr',
    );

    /**
     * 編集view出力
     * @param array $row
     */
    public function edit_view($row)
    {
        // 参照指定がある場合は子HTMLを出力
        if (strlen($this->ref_id) > 0) {
            $child = $this->get_child_node();
            echo $child->node_value;
            return;
        }

        h::no_escape($this->output($row, true));
    }

    /**
     * 出力
     * @param array $row
     * @param boolean $edit_mode
     * @return string
     */
    public function output($row, $edit_mode = false)
    {
        if ($edit_mode) {
            if (strlen($row['node_value']) < 1) {
                $row['node_value'] = CMS_PATH . self::NO_IMAGE;
                if (!empty($this->resize)) {
                    $resize_list = explode(',', $this->resize);
                    if (isset($resize_list[0])) {
                        list($row['attr']['width'], $row['attr']['height']) = explode(self::RESIZE_SEPARATOR, $resize_list[0], 2);
                    }
                }
            }
        } else {
            if (strlen($row['node_value']) < 1) {
                return '';
            }
        }
        // 相対パスに変換する
        $node_value = Me_Util::get_relative_path($row['ref_link_path'], $row['node_value']);

        $exclude_attr_list = Me_Util::get_array($this->exclude_attr, true);

        $suffix = '';
        // １つ目の画像はsuffixを省略するので2以上の場合にsuffixを付ける。
        if (strlen($this->suffix) > 0 && $this->suffix >= 2) {
            $suffix = '-' . $this->suffix;
            $node_value = preg_replace('/\.[^\.]*$/', $suffix . '$0', $node_value);
        }

        $img_attr = array();
        $child_node = $this->get_child_node();
        if ($child_node !== null && isset($child_node->img_attr)) {
            $img_attr = $child_node->img_attr;
        }
        if (isset($row['attr']['width']) && !isset($exclude_attr_list['width'])) {
            $img_attr['width'] = $row['attr']['width' . $suffix];
        }
        if (isset($row['attr']['height']) && !isset($exclude_attr_list['height'])) {
            $img_attr['height'] = $row['attr']['height' . $suffix];
        }
        if (isset($row['attr']['title']) && !isset($exclude_attr_list['title'])) {
            $img_attr['title'] = $row['attr']['title'];
        }
        if (isset($row['attr']['alt']) && !isset($exclude_attr_list['alt'])) {
            $img_attr['alt'] = $row['attr']['alt'];
        }

        if ($edit_mode) {
            // border色指定
            $border_color = $this->get_border_color($row['repeat_no']);
            $img_attr['style'] = 'border: 1px solid ' . $border_color . '; cursor: pointer;';
            $img_attr['onclick'] = $this->get_open_method($row);
        }

        $str = '<img ';
        if (!isset($exclude_attr_list['src'])) {
            $img_attr['src'] = $node_value;
        }
        foreach ($img_attr as $key => $val) {
            if (strlen($val) < 1) {
                continue;
            }
            if (substr($key, 0, 1) === 'on') {
                // onで始まる属性はエスケープせずに出力する。
                $str .= $key . '="' . $val . '" ';
            } else {
                $str .= $key . '="' . Me_Util::html_escape($val) . '" ';
            }
        }
        if (Me_Config::get('xhtml', 'template')) {
            $str .= ' /';
        }
        $str .= '>';

        $this->set_url($row);
        list($a_open, $a_close) = $this->get_a($row, $exclude_attr_list);
        $anchor = $this->get_anchor($row);

        return $anchor . $a_open . $str . $a_close;
    }

    /**
     * editor
     */
    public function print_editor_attr()
    {
        $str = '';
        if (!empty($this->style)) {
            $str .= ' style="' . Me_Util::html_escape($this->style) . '"';
        }
        h::no_escape($str);
    }

    /**
     * タグ編集
     */
    public function set_post_data()
    {
        $mapping = $this->attr_list;
        $mapping['selected_text'] = 'selected_text';
        Me_Util::post_data_to_object($this, $mapping);
    }

    /**
     * tag生成機能の初期値設定
     * @param string $text
     */
    public function set_initial_attr_value($text)
    {
        parent::set_initial_attr_value($text);

        // imgタグの属性を抽出
        if (preg_match('/<img.*?>/i', $text, $matches_img)) {
            // 属性を取得
            $width = null;
            $height = null;
            preg_match_all('/[[:alnum:]_]+=(""|".*?[^\\\\]"|\'\'|\'.*?[^\\\\]\')/', $matches_img[0], $matches_img_attr);
            foreach ($matches_img_attr[0] as $match) {
                list($attr_name, $attr_value) = explode('=', $match, 2);
                $attr_name = strtolower($attr_name);
                $attr_value = substr($attr_value, 1, strlen($attr_value) - 2);

                if ($attr_name === 'width') {
                    $width = $attr_value;
                } else if ($attr_name === 'height') {
                    $height = $attr_value;
                }
            }
            if (!empty($width) || !empty($height)) {
                $this->resize = $width . self::RESIZE_SEPARATOR . $height;
            }
        }
    }
}