<?php
/**
 * Metag Source
 * @package     Metag
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Metag_Source extends Metag
{
    /** editor cols */
    const EDITOR_COLS = '40';
    /** editor rows */
    const EDITOR_ROWS = '5';
    /**
     * タグタイプ
     * @var string
     */
    public $node_type = 'source';
    /**
     * 表示名
     * @var string
     */
    public $display_name = 'ソース (source)';
    /**
     * ブロック要素かどうか
     * @var boolean
     */
    public $is_block = false;
    /**
     * cols attribute
     * @var string
     */
    public $cols;
    /**
     * rows attribute
     * @var string
     */
    public $rows;
    /**
     * style attribute
     * @var string
     */
    public $style;
    /**
     * 編集アイコンの表示
     * @var string
     */
    public $edit_icon;
    /**
     * 属性リスト
     * @var array
     */
    public $attr_list = array(
        'id' => 'id',
        'cols' => 'cols',
        'rows' => 'rows',
        'style' => 'style',
        'edit_icon' => 'edit_icon',
        'ref_id' => 'ref_id',
        'ref_page_id' => 'ref_page_id',
    );

    /**
     * 編集view出力
     * @param array $row
     */
    public function edit_view(&$row)
    {
        // 参照指定がある場合は子HTMLを出力
        if (strlen($this->ref_id) > 0) {
            $child = $this->get_child_node();
            echo $child->node_value;
            return;
        }

        if ($this->edit_icon === 'on') {
            h::no_escape('<img class="me_edit_icon" src="' . CMS_PATH . '/app/assets/img/silk/script_edit.png" width="16" height="16" title="ソース編集" onclick="'
                . $this->get_open_method($row) . '"'
                . $this->get_icon_style($row['repeat_no']) . '>'
                . '<span class="metag">'
                . $this->output($row, true)
                . '</span>'
            );
        } else {
            h::no_escape('<span class="metag" onclick="' . $this->get_open_method($row) . '"'
                . $this->get_style($row['repeat_no']) . '>'
                . $this->output($row, true)
                . '</span>');
        }
    }

    /**
     * 出力
     * @param array $row
     * @param boolean $edit_mode
     */
    public function output($row, $edit_mode = false)
    {
        $ret = '';
        if ($edit_mode && (strlen($row['node_value']) < 1 || preg_match('/^[[:cntrl:][:blank:]]+$/', $row['node_value']))) {
            $ret = Metag_Logic::BLANK;
        } else {
            $ret = $row['node_value'];
        }
        return $ret;
    }

    /**
     * editor
     */
    public function print_editor_attr()
    {
        $str = '';
        $cols = (empty($this->cols)) ? self::EDITOR_COLS : $this->cols;
        $str .= ' cols="' . Me_Util::html_escape($cols) . '"';
        $rows = (empty($this->rows)) ? self::EDITOR_ROWS : $this->rows;
        $str .= ' rows="' . Me_Util::html_escape($rows) . '"';
        if (!empty($this->style)) {
            $str .= ' style="' . Me_Util::html_escape($this->style) . '"';
        }

        h::no_escape($str);
    }

    /**
     * タグ編集
     */
    public function set_post_data()
    {
        $mapping = $this->attr_list;
        $mapping['selected_text'] = 'selected_text';
        Me_Util::post_data_to_object($this, $mapping);
    }
}